"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const deepmerge = require("deepmerge");
const config_1 = require("./config");
function Service(config) {
    return (constructor) => {
        const functionConfigs = constructor[config_1.FUNCTIONS_METADATA];
        if (config && functionConfigs) {
            for (const key in functionConfigs) {
                functionConfigs[key] = deepmerge(config, functionConfigs[key]);
            }
        }
        const envProperties = constructor[config_1.ENV_METADATA];
        if (envProperties) {
            return classWithEnvProperties(constructor, envProperties);
        }
    };
}
exports.Service = Service;
function classWithEnvProperties(constructorFn, envProperties) {
    return class extends constructorFn {
        constructor(...args) {
            super(...args);
            if (Array.isArray(envProperties)) {
                for (const prop of envProperties) {
                    if (process.env[prop.envName] !== undefined) {
                        this[prop.key] = process.env[prop.envName];
                    }
                }
            }
        }
    };
}
